@@ -29,10 +29,11 @@ class JsonQuickbaseClient(QuickbaseClient):
         while tries < 10:
             try:
                 return self._request(url, action, params=params, body=body, json=json)
-            except ConnectionError or QBResponseError:
+            except requests.exceptions.Timeout or QBResponseError:
                 tries += 1
                 time.sleep(1)
                 pass
+        raise QBConnectionError('Connection Error: Timeout')
 
     def _request(self, url, action, params=None, body=None, json=True):
         kwargs = {
