@@ -36,13 +36,21 @@ class XmlQuickbaseClient(QuickbaseClient):
                 'content-type': 'application/xml',
                 'QUICKBASE-ACTION': f'API_{action}',
             }
-        while True:
+        tries = 0
+        while tries < 10:
             try:
-                response = self._make_request(url, data, headers, type)
-                break
-            except requests.exceptions.Timeout:
+                return self._make_request(url, data, headers, type)
+            except requests.exceptions.Timeout or QBConnectionError:
                 print('Timeout error, retrying...')
+                tries += 1
                 time.sleep(1)
+        raise QBConnectionError('Connection Error: Timeout')
+
+    def _make_request(self, url, data, headers, type):
+        if type == 'POST':
+            response =  requests.post(url, data=data, headers=headers, timeout=self.timeout)
+        elif type == 'GET':
+            response = requests.get(url, headers=headers, timeout=self.timeout)
 
         if response.status_code == 401 or response.status_code == 403:
             raise QBAuthError('Invalid credentials')
@@ -57,12 +65,6 @@ class XmlQuickbaseClient(QuickbaseClient):
         
         return response.content
 
-    def _make_request(self, url, data, headers, type):
-        if type == 'POST':
-            return requests.post(url, data=data, headers=headers, timeout=self.timeout)
-        elif type == 'GET':
-            return requests.get(url, headers=headers, timeout=self.timeout)
-
     def _build_xml(self, data):
         if self.ticket:
             data['ticket'] = self.ticket
